CREATE TABLE CREDIT_LIMIT_TYPE (
  ID_CREDIT_LIMIT_TYPE NUMBER NOT NULL,
  DESCRIPTION VARCHAR2(200 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT CREDIT_LIMIT_TYPE_PK PRIMARY KEY (ID_CREDIT_LIMIT_TYPE)
);

CREATE SEQUENCE CREDIT_LIMIT_TYPE_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 100 NOCACHE NOORDER  NOCYCLE;

INSERT INTO CREDIT_LIMIT_TYPE(ID_CREDIT_LIMIT_TYPE, DESCRIPTION, ACTIVE) 
VALUES (1, 'Transfer income', 'Y');

CREATE TABLE CREDIT_LIMIT (
  ID_CREDIT_LIMIT NUMBER NOT NULL,
  ID_LASTNIKA NUMBER,
  ID_TYPE NUMBER,
  DATE_FROM DATE,
  DATE_TO DATE,
  AMOUNT NUMBER,
  "COMMENT" VARCHAR2(500 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT CREDIT_LIMIT_PK PRIMARY KEY (ID_CREDIT_LIMIT),
  CONSTRAINT CREDIT_LIMIT_ID_LASTNIKA_FK FOREIGN KEY (ID_LASTNIKA) REFERENCES KUPCI(ID),
  CONSTRAINT CREDIT_LIMIT_ID_TYPE_FK FOREIGN KEY (ID_TYPE) REFERENCES CREDIT_LIMIT_TYPE(ID_CREDIT_LIMIT_TYPE)
);

CREATE INDEX IX_CREDIT_LIMIT_ID_LASTNIKA ON CREDIT_LIMIT (ID_LASTNIKA);
CREATE INDEX IX_CREDIT_LIMIT_ID_TYPE ON CREDIT_LIMIT (ID_TYPE);

CREATE SEQUENCE CREDIT_LIMIT_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE OR REPLACE VIEW V_CREDIT_LIMIT AS (
  SELECT CL.ID_CREDIT_LIMIT, CL.ID_LASTNIKA, CL.ID_TYPE, CL.DATE_FROM, CL.DATE_TO, CL.AMOUNT, CL."COMMENT", CL.ACTIVE, CLT.DESCRIPTION AS TYPE_DESCRIPTION, 
  (CASE WHEN (SELECT VREDNOST FROM S_NASTAVITVE WHERE FILTER = 'MARINA' AND SEKCIJA = 'MARINA' AND NAZIV = 'ChangeFirstLastName') = '1' THEN (KU.IME || ' ' || KU.PRIIMEK) ELSE (KU.PRIIMEK || ' ' || KU.IME) END) AS OWNER
  FROM CREDIT_LIMIT CL 
  LEFT OUTER JOIN CREDIT_LIMIT_TYPE CLT ON CLT.ID_CREDIT_LIMIT_TYPE = CL.ID_TYPE
  LEFT OUTER JOIN KUPCI KU ON KU.ID = CL.ID_LASTNIKA
);

ALTER TABLE FB_LOCATION
ADD INCOME_TRANSFER_SERVICE VARCHAR2(6 CHAR);

ALTER TABLE M_STORITVE
ADD ID_SALDKONT_GEN NUMBER;

DROP VIEW V_STORITVE;

CREATE OR REPLACE VIEW V_STORITVE AS (
	SELECT M.ID_STORITVE, M.ID_DN, M.ID_POGODBE, M.ID_VPS, M.VRSTA, M.ID_LASTNIKA, M.ID_PLOVILA, M.STORITEV, M.KAT, M.TIMEKAT, M.PROCKAT, M.DATUM_OD, M.DATUM_DO, M.KOLICINA, M.POPUST, M.OPIS_SERVIS,
  M.ZNESEK, M.VALUTA, M.TECAJ, M.DAVEK, M.N_PONUDBE, M.N_RACUNA, M.DATUM_RACUNA, M.ZAKLJUCEN, M.KOMENTAR, M.DATUM_KREIRANJA, M.USER_KREIRANJA, M.DATUM_SPREMEMBE, M.USER_SPREMEMBE, M.TIP_SERVIS, M.AUTO,
  M.POPUST1, M.POPUST2, M.NAMENP, M.NAMENP1, M.NAMENP2, M.TECAJP, M.DODATNA_STORITEV, M.DOMACA_VALUTA, M.PROVIZIJA, M.DRZAVA, M.SKUPAJ_OSEB, M.ID_KAT, M.PROVIZIJA_DELITEV, M.ID_REZERVACIJE, M.CUSTOM,
  M.CPROVIZIJA, M.SERVICE_COST, M.COMPLETE, M.KOLICINA_INSTR, M.ID_STORITVE_GEN, M.ID_BATCH, M.ID_SALDKONT, M.ID_LASTNIKA_ORG, M.NNLOCATION_ID, M.MIN_FEE, M.ID_LASTNIK_LEASE, 
  M.NCARD, M.FULL_AMOUNT, M.SERVICE_TIME, M.ID_PRIVEZ, M.SUBLEASE_PAYMENT, M.ID_DAVEK, M.LASTNIK_LEASE_PROCENT, M.ID_REZERVACIJE_CHARTER, M.ID_SERVICE_TEMPLATE, M.CAS_OD, M.CAS_DO, M.USER_COMMENT, M.SERVICE_COMMENT,
  M.ID_OWNER_SIGNATURE, M.ID_NAJAVE, M.SORT, M.ID_IMPORT_BATCH, M.CALCULATING, M.CALCULATED_TO, M.ID_STORITVE_STORNO, M.WORKERS_CHARGEABLE, M.ID_SALDKONT_GEN,
  NS.OPIS AS NNSTOMAR_OPIS, NS.INTERNI_OPIS AS NNSTOMAR_INTERNI_OPIS, NS.DAVEK AS NNSTOMAR_DAVEK, NS.KAT AS NNSTOMAR_KAT, NS.TIMEKAT AS NNSTOMAR_TIMEKAT, NS.ENOTA AS NNSTOMAR_ENOTA, NS.FILTER AS NNSTOMAR_FILTER,
  NS.DEPARTURE_CHECK AS NNSTOMAR_DEPARTURE_CHECK, NS.NIGHTS_PRICE AS NNSTOMAR_NIGHTS_PRICE, NS.WORKERS AS NNSTOMAR_WORKERS,
  NNE.OPIS AS NNSTOMAR_ENOTA_OPIS, NNE.INTERNI_OPIS AS NNSTOMAR_ENOTA_INTERNI_OPIS, MDN.DATUM_DN AS M_DE_NA_DATUM_DN, MDN.TERMIN_DO AS M_DE_NA_TERMIN_DO, MDN.STEVILKA AS M_DE_NA_STEVILKA,
  MDN.STATUS AS M_DE_NA_STATUS, MDN.ORG_STATUS AS M_DE_NA_ORG_STATUS, MDN.TYPE AS M_DE_NA_TYPE, PL.IME AS PLOVILA_IME,
  KU.IME AS KUPCI_IME, KU.PRIIMEK AS KUPCI_PRIIMEK, KU.MANAGER AS KUPCI_MANAGER, KU.VRSTA AS KUPCI_VRSTA,
  (CASE WHEN (SELECT VREDNOST FROM S_NASTAVITVE WHERE FILTER = 'MARINA' AND SEKCIJA = 'MARINA' AND NAZIV = 'ChangeFirstLastName') = '1' THEN (KU.IME || ' ' || KU.PRIIMEK) ELSE (KU.PRIIMEK || ' ' || KU.IME) END) AS OWNER
	FROM M_STORITVE M
  LEFT OUTER JOIN M_NNSTOMAR NS ON NS.SIFRA = M.STORITEV
  LEFT OUTER JOIN NNENOTE NNE ON NNE.SIFRA = NS.ENOTA
  LEFT OUTER JOIN M_DE_NA MDN ON MDN.ID_DN = M.ID_DN
  LEFT OUTER JOIN KUPCI KU ON KU.ID = M.ID_LASTNIKA
  LEFT OUTER JOIN PLOVILA PL ON PL.ID = M.ID_PLOVILA
);

DROP INDEX IX_PRIKLJ1;

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (1582, SYSDATE, '5.5', 1502, 'Credit limit')
;